.. raw:: html

  <style type="text/css">
    li.toctree-l1 {
        padding: 0.5em 0 1em 0 ;
        list-style-type: none;
        font-size: 150% ;
        }

    li.toctree-l2 {
        font-size: 70% ;
        list-style-type: square;
        }

    li.toctree-l3 {
        font-size: 85% ;
        list-style-type: circle;
        }

    div.bodywrapper blockquote {
	margin: 0 ;
    }

  </style>


.. raw:: html

    <h1 style='text-align: center; font-size: 270%;'>
    Joblib: running Python functions as pipeline jobs
    </h1>

Introduction
------------


.. automodule:: joblib

User manual
--------------

 .. toctree::
    :maxdepth: 2

    why.rst
    installing.rst
    memory.rst
    parallel.rst
    persistence.rst
    developing.rst

Module reference
-----------------

.. currentmodule:: joblib

.. autosummary::
   :toctree: generated

   Memory
   Parallel
   dump
   load
   hash
